[![Build Status](https://travis-ci.org/kwinata/pacco.svg?branch=release)](https://travis-ci.org/kwinata/pacco)
[![PyPi version](https://pypip.in/v/pacco/badge.png)](https://pypi.org/project/pacco/)
[![Maintainability](https://api.codeclimate.com/v1/badges/25d9932adf5b9cb51bbe/maintainability)](https://codeclimate.com/github/kwinata/pacco/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/25d9932adf5b9cb51bbe/test_coverage)](https://codeclimate.com/github/kwinata/pacco/test_coverage)

# Pacco
![](docs/source/_images/pacco.png)

Pacco is a simple package manager (used for prebuilt binary) that is interoperable with Nexus repository manager.

## Documentation

Check out our documentation [here!](https://kwinata.github.io/pacco)

## Install
For the latest stable release, install by
```
pip install pacco
```
For the dev release, install by
```
git clone --single-branch --branch dev https://github.com/kwinata/pacco
cd pacco
pip install .
```
